@@ -1,15 +1,15 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic-More/lib/Perl/Critic/More.pm $
-#     $Date: 2007-08-08 20:17:06 -0500 (Wed, 08 Aug 2007) $
+#     $Date: 2007-08-12 11:37:37 -0500 (Sun, 12 Aug 2007) $
 #   $Author: chrisdolan $
-# $Revision: 1825 $
+# $Revision: 1831 $
 ##############################################################################
 package Perl::Critic::More;
 
-use v5.6;
+use 5.006;
 use warnings;
 use strict;
-our $VERSION = 0.15;
+our $VERSION = 0.16;
 
 1;
 
@@ -102,7 +102,7 @@ L<http://perlcritic.tigris.org>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006 Chris Dolan
+Copyright (c) 2006-2007 Chris Dolan
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
