@@ -1,13 +1,13 @@
 #######################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic-More/lib/Perl/Critic/Policy/ValuesAndExpressions/RestrictLongStrings.pm $
-#     $Date: 2007-08-08 20:17:06 -0500 (Wed, 08 Aug 2007) $
+#     $Date: 2007-08-12 11:37:37 -0500 (Sun, 12 Aug 2007) $
 #   $Author: chrisdolan $
-# $Revision: 1825 $
+# $Revision: 1831 $
 ########################################################################
 
 package Perl::Critic::Policy::ValuesAndExpressions::RestrictLongStrings;
 
-use v5.6;
+use 5.006;
 use strict;
 use warnings;
 use Carp;
@@ -15,7 +15,7 @@ use Readonly;
 use Perl::Critic::Utils qw{ :severities };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = 0.15;
+our $VERSION = 0.16;
 
 Readonly my $DEFAULT_MAX_STRING_LENGTH => 78;
 
@@ -115,7 +115,7 @@ Chris Dolan <cdolan@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006 Chris Dolan
+Copyright (c) 2006-2007 Chris Dolan
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
